==> metrium-0.1.0.zip: metrium-0.1.0/src/metrium/models/omni.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Metrium System
# Copyright (C) 2008-2014 Hive Solutions Lda.
#
# This file is part of Hive Metrium System.
#
# Hive Metrium System is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Hive Metrium System is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Hive Metrium System. If not, see <http://www.gnu.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2014 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "GNU General Public License (GPL), Version 3"
""" The license for the module """

from metrium.models import base

class Omni(base.Base):

    sales_total = dict(
        type = list,
        index = True
    )

    sales_data = dict(
        type = list,
        index = True
    )

    sales_stores = dict(
        type = list,
        index = True
    )

    top_stores = dict(
        type = list,
        index = True
    )

    top_employees = dict(
        type = list,
        index = True
    )

    @classmethod
    def get_state(cls):
        omni = cls.get(raise_e = False)
        if not omni: return dict()
        return {
            "omni.sales_total" : [{
                "sales_total" : omni.sales_total
            }],
            "omni.sales_data" : [{
                "sales_data" : omni.sales_data
            }],
            "omni.sales_stores" : [{
                "sales_stores" : omni.sales_stores
            }],
            "omni.top_stores" : [{
                "top_stores" : omni.top_stores
            }],
            "omni.top_employees" : [{
                "top_employees" : omni.top_employees
            }]
        }

==> metrium-0.1.5.zip: metrium-0.1.5/src/metrium/models/omni.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Metrium System
# Copyright (C) 2008-2015 Hive Solutions Lda.
#
# This file is part of Hive Metrium System.
#
# Hive Metrium System is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Hive Metrium System is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Hive Metrium System. If not, see <http://www.gnu.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "GNU General Public License (GPL), Version 3"
""" The license for the module """

from . import base

class Omni(base.Base):

    sales_total = dict(
        type = list,
        index = True
    )

    sales_data = dict(
        type = list,
        index = True
    )

    sales_stores = dict(
        type = list,
        index = True
    )

    entries_stores = dict(
        type = list,
        index = True
    )

    top_stores = dict(
        type = list,
        index = True
    )

    top_employees = dict(
        type = list,
        index = True
    )

    @classmethod
    def get_state(cls):
        omni = cls.get(raise_e = False)
        if not omni: return dict()
        return {
            "omni.sales_total" : [{
                "sales_total" : omni.sales_total
            }],
            "omni.sales_data" : [{
                "sales_data" : omni.sales_data
            }],
            "omni.sales_stores" : [{
                "sales_stores" : omni.sales_stores
            }],
            "omni.entries_stores" : [{
                "entries_stores" : omni.entries_stores
            }],
            "omni.top_stores" : [{
                "top_stores" : omni.top_stores
            }],
            "omni.top_employees" : [{
                "top_employees" : omni.top_employees
            }]
        }
